@@ -3,7 +3,7 @@
 from django.conf import settings
 from django.core.urlresolvers import resolve
 
-from core.utils.site import get_default_site_url
+from .site import get_default_site_url
 
 
 def company_name(request):
